.. image:: https://img.shields.io/pypi/v/jaraco.env.svg
   :target: https://pypi.org/project/jaraco.env

.. image:: https://img.shields.io/pypi/pyversions/jaraco.env.svg

.. image:: https://github.com/jaraco/jaraco.env/workflows/tests/badge.svg
   :target: https://github.com/jaraco/jaraco.env/actions?query=workflow%3A%22tests%22
   :alt: tests

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black
   :alt: Code style: Black

.. .. image:: https://readthedocs.org/projects/jaracoenv/badge/?version=latest
..    :target: https://jaracoenv.readthedocs.io/en/latest/?badge=latest

.. image:: https://img.shields.io/badge/skeleton-2023-informational
   :target: https://blog.jaraco.com/skeleton


This library facilitates handling of environment variables.


Check
=====

Use ``Check`` to act as a boolean gate on an environment variable.
